==> siag_3.0.6.orig.tar.gz: siag-3.0.6/xcommon/RichtextP.h <==
/*
   Copyright (C) 1998  Ulric Eriksson <ulric@edu.stockholm.se>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the Licence, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public
   License along with this library; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330, Boston,
   MA 02111-1307, USA.
 */

#ifndef s_RichtextP_h
#define s_RichtextP_h

#include "Richtext.h"
/* include superclass private header file */
#include <X11/CoreP.h>

/* define unique representation types not found in <X11/StringDefs.h> */

#define XtRRichtextResource "RichtextResource"

typedef struct {
    int empty;
} RichtextClassPart;

typedef struct s_RichtextClassRec {
    CoreClassPart	core_class;
    CompositeClassPart	composite_class;
    RichtextClassPart	richtext_class;
} RichtextClassRec;

extern RichtextClassRec richtextClassRec;

typedef struct {
    /* resources */
	int top_row, top_col;
	int sel_top_row, sel_top_col;
	int sel_bottom_row, sel_bottom_col;
	int point_row, point_col;
	int (*row_height)(XtPointer, int);
	int (*style)(XtPointer, int);
	int (*adj_horiz)(XtPointer, int);
	rich_char *(*text)(XtPointer, int);
	XtPointer data;
	Boolean redisplay;
	Boolean visible_cursor;
	int paper_width, left_margin, right_margin;
	void (*plugin_coords)(Widget, XtPointer, long *, long *);
    /* private state */
	GC clear_gc;
	GC cell_gc;
	GC cursor_gc;
} RichtextPart;

typedef struct s_RichtextRec {
    CorePart		core;
    CompositePart	composite;
    RichtextPart	richtext;
} RichtextRec;

#endif /* s_RichtextP_h */

==> siag_3.1.22.orig.tar.gz: siag-3.1.22/xcommon/RichtextP.h <==
/*
   Copyright (C) 1998-1999  Ulric Eriksson <ulric@edu.stockholm.se>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the Licence, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public
   License along with this library; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330, Boston,
   MA 02111-1307, USA.
 */

#ifndef s_RichtextP_h
#define s_RichtextP_h

#include "../config.h"

#include "Richtext.h"
/* include superclass private header file */
#include <X11/CoreP.h>

/* define unique representation types not found in <X11/StringDefs.h> */

#define XtRRichtextResource "RichtextResource"

typedef struct {
    int empty;
} RichtextClassPart;

typedef struct s_RichtextClassRec {
    CoreClassPart	core_class;
    CompositeClassPart	composite_class;
    RichtextClassPart	richtext_class;
} RichtextClassRec;

extern RichtextClassRec richtextClassRec;

typedef struct {
    /* resources */
	int top_row, top_col;
	int sel_top_row, sel_top_col;
	int sel_bottom_row, sel_bottom_col;
	int point_row, point_col;
	int (*row_height)(XtPointer, int);
	int (*style)(XtPointer, int);
	int (*adj_horiz)(XtPointer, int);
	rich_char *(*text)(XtPointer, int);
	XtPointer data;
	Boolean redisplay;
	Boolean visible_cursor;
	int paper_width, left_margin, right_margin;
	int tab_distance;
	void (*plugin_coords)(Widget, XtPointer, int *, int *);
	Boolean (*bop)(XtPointer, int);
    /* private state */
	GC clear_gc;
	GC cell_gc;
	GC cursor_gc;
#ifdef HAVE_XCREATEIC
	XIM xim;
	XIC xic;
#endif
} RichtextPart;

typedef struct s_RichtextRec {
    CorePart		core;
    CompositePart	composite;
    RichtextPart	richtext;
} RichtextRec;

#endif /* s_RichtextP_h */
